==> Java-Swing-0.02.tar.gz: Java-Swing-0.02/java/PerlContainerListener.java <==
import java.awt.event.ContainerListener;
import org.perl.inline.java.*;

public class      PerlContainerListener
       extends    InlineJavaPerlCaller
       implements ContainerListener
{
    String sender;
    String callbacks;

    public PerlContainerListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void componentAdded(java.awt.event.ContainerEvent event) {
        try {
            CallPerl(
                "Java::Swing::ContainerListener",
                "_ContainerListener",
                new Object[] {sender, callbacks, "componentAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentRemoved(java.awt.event.ContainerEvent event) {
        try {
            CallPerl(
                "Java::Swing::ContainerListener",
                "_ContainerListener",
                new Object[] {sender, callbacks, "componentRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.14.tar.gz: Java-Swing-0.14/java/PerlContainerListener.java <==
import java.awt.event.ContainerListener;
import org.perl.inline.java.*;

public class      PerlContainerListener
       extends    InlineJavaPerlCaller
       implements ContainerListener
{
    String sender;
    String callbacks;

    public PerlContainerListener() throws InlineJavaException { }

    public PerlContainerListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void componentAdded(java.awt.event.ContainerEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "componentAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void componentRemoved(java.awt.event.ContainerEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "componentRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
